@@ -54,7 +54,7 @@ import Language.Haskell.TH
 import Language.Haskell.TH.Quote   ( QuasiQuoter(..) )
 
 import Data.String.Interpolate.Conversion
-  ( build, finalize, interpolate, ofString )
+  ( build, finalize, interpolate, ofString, chompSpaces )
 import Data.String.Interpolate.Parse      ( InterpSegment(..), dosToUnix, parseInterpSegments )
 
 i :: QuasiQuoter
