@@ -1,26 +1,26 @@
 {-# OPTIONS -Wno-orphans #-}
-{-# LANGUAGE QuasiQuotes #-}
-{-# LANGUAGE ScopedTypeVariables #-}
-{-# LANGUAGE OverloadedStrings #-}
-{-# LANGUAGE PackageImports #-}
-{-# LANGUAGE TypeApplications #-}
+{-# LANGUAGE AllowAmbiguousTypes        #-}
+{-# LANGUAGE DerivingStrategies         #-}
+{-# LANGUAGE FlexibleContexts           #-}
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
-{-# LANGUAGE DerivingStrategies #-}
-{-# LANGUAGE AllowAmbiguousTypes #-}
-{-# LANGUAGE TypeFamilies #-}
-{-# LANGUAGE FlexibleContexts #-}
+{-# LANGUAGE OverloadedStrings          #-}
+{-# LANGUAGE PackageImports             #-}
+{-# LANGUAGE QuasiQuotes                #-}
+{-# LANGUAGE ScopedTypeVariables        #-}
+{-# LANGUAGE TypeApplications           #-}
+{-# LANGUAGE TypeFamilies               #-}
 
-import           Data.Word
-import           Data.Char ( chr, isSpace )
-import qualified Data.Text as T
-import qualified Data.Text.Lazy as LT
-import qualified Data.ByteString as B
-import qualified Data.ByteString.Lazy as LB
+import qualified Data.ByteString         as B
 import qualified Data.ByteString.Builder as LB
-import           Data.List ( sort )
+import qualified Data.ByteString.Lazy    as LB
+import           Data.Char               ( chr, isSpace )
+import           Data.Foldable           ( foldMap )
+import qualified Data.HashMap.Strict     as HM
+import           Data.List               ( sort )
 import           Data.Semigroup
-import           Data.Foldable ( foldMap )
-import qualified Data.HashMap.Strict as HM
+import qualified Data.Text               as T
+import qualified Data.Text.Lazy          as LT
+import           Data.Word
 
 import Control.Monad.IO.Class ( liftIO )
 
@@ -29,16 +29,26 @@ import System.Random.Shuffle
 import "hspec" Test.Hspec
 import "hspec" Test.Hspec.QuickCheck
 import "QuickCheck" Test.QuickCheck
-import "QuickCheck" Test.QuickCheck.Monadic
 import "quickcheck-instances" Test.QuickCheck.Instances.ByteString ()
+import "QuickCheck" Test.QuickCheck.Monadic
 import "quickcheck-unicode" Test.QuickCheck.Unicode
 
 import Data.String.Interpolate ( i, iii )
-import Data.String.Interpolate.Conversion
+import Data.String.Interpolate.Conversion hiding
+  ( build, finalize, interpolate, ofString, chompSpaces )
 
 main :: IO ()
 main = hspec $ parallel $ do
   describe "i" $ modifyMaxSuccess (const 10000) $ modifyMaxSize (const 500) $ do
+    it "should allow an escaped backslash right before an interp" $ do
+      let var :: String = "bar"
+          expected :: String = "foo\\bar"
+      [i|foo\\#{var}|] `shouldBe` expected
+
+    it "should only esacpe verbatim segments a single time" $ do
+      let expected :: String = "\\\\\\\\"
+      [i|\\\\\\\\|] `shouldBe` expected
+
     context "when using String as a parameter" $ do
       prop "just interpolating should be id" $
         \(UTF8S str) -> [i|#{str}|] == str
@@ -451,7 +461,7 @@ instance Arbitrary NonwhitespaceText where
 charFrequencies :: T.Text -> HM.HashMap Char Int
 charFrequencies = T.foldl' (flip $ HM.alter increment) HM.empty . T.filter (not . isSpace)
   where increment :: Maybe Int -> Maybe Int
-        increment Nothing = Just 1
+        increment Nothing  = Just 1
         increment (Just x) = Just (x + 1)
 
 whitespace :: Gen T.Text
